Python: class VirtualEnvInfo

VirtualEnvOnDemand.VirtualEnvInfo = class VirtualEnvInfo(__builtin__.object)
`` |  | Methods defined here: __getitem__(self, name) __init__(self, virtualenvDirectory, sitePackagesDirectory='') `@param virtualenvDirectory <str> - Path to the root of the virtualenv @param sitePackagesDirectory <str> - Path to the site packages directory (goes into PYTHONPATH) If virtualenvDirectory is provided, sitePackagesDirectory will be calculated with default expected values. This object should be considered read-only. If you need to modify values, you must create a new object.` validate(self) `validate - Validate that the virtualenv exists in the expected way. @raises ValueError - With message indicating the reason for failure @return <bool> - True` Data descriptors defined here: sitePackagesDirectory virtualenvDirectory